@@ -1,3 +1,10 @@
+# This is file spam0.15-3/demo/spam.R
+# This file is part of the spam package, 
+#      http://www.mines.edu/~rfurrer/software/spam/
+# written and maintained by Reinhard Furrer.
+
+
+
 # This is a simple demo, wrapping up the functionality of spam.
 
 
@@ -55,7 +62,7 @@ display(smat, main="'scatterplot'-type display, very efficient")
 
 
 
-spam.options(imagesize=prod(smat@dimension)+1)
+.Spam$imagesize <- prod(smat@dimension)+1
 display(smat, main="'image'-type display, may be slow and heavy")
 
 par(opar)
